/* ************************************************************************** */
/** Descriptive File Name:  Lab 3b.c LCD Control using bit banging
                            frequency tones.

  @ Author
    Richard Wall
 
  @ Date
    Created:    August 12, 2013
    Revised:    February 4, 2014
                December 15, 2015 - MPLAB X v2.26 - XC32 1.34
    Verified:   May 16, 2017 - MPLAB X v3.61 - XC32 v1.43

  @Company
    Digilent Inc

  @Development Environment
    MPLAB X IDE x3.61 - http://www.microchip.com/mplab/mplab-x-ide 
	XC32 1.43 - http://www.microchip.com/mplab/compilers
	PLIB 3/7/20162 - http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library

  @File Name
    lab3.c

  @Summary
    Demonstration of bit-bang interface with a character LCD

  @Description
    This project is an application to test the control of a 
    character LCD. Define WRITE_LCD_TEST to run the LCD text
    writing capability. Define TIME_LCD_TEST to run a program that
    allows easy observing the handshaking signals.  Refer to
    LCDBBlib.c for specific LCD operations.
 
  @Remarks
    Uses XC32 peripheral library. See 
 http://ww1.microchip.com/downloads/en/DeviceDoc/32bitPeripheralLibraryGuide.pdf
 http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library
  
 ****   This application uses a peripheral bus clock set to 10MHz.  ****
    PBCLK set for 10 MHz, Set parameters in config_bits.h and hardware.h 
 ***************************************************************************/

#define WRITE_LCD_TEST      // Text writing to LCD
// #define TIME_LCD_TEST    // Handshaking timing

/* Included files for platform */
#include "hardware.h"
#include "config_bits.h"
#include "swDelay.h"

/* Included files for system */
#include <plib.h>
#include <stdio.h>

/* Included files for application */
#include "Lab3.h"
#include "LCDlib.h"

int main(void)
{
int loop_counter = 0;
char num_str[8];

    Hardware_Setup();
    initLCD();

#ifdef WRITE_LCD_TEST

    putsLCD( "Basys MX3");
    setLCDC(0x40);	// Position cursor to second line
    putsLCD( "LCD Lab 3b");
    while(1)
    {
    	setLCDC( 0x4B );
        putsLCD("  ");
    	setLCDC( 0x4B );
    	sprintf(num_str,"%02d",loop_counter);
        putsLCD(num_str);
    	msDelay(1000);
        ++loop_counter; 
    }
#endif

#ifdef TIME_LCD_TEST
    while( 1)
    {
	putLCD('A');
	DelayMs(1);
	putLCD('B');
	DelayMs(1);
    }
#endif
    return 1;
}

// End of project6.c

