/* ************************************************************************** */
/** Descriptive File Name

  @ Author
    Richard Wall
 
  @ Date
    Created: October 8, 2016
    Verified: May 16, 2017

  @Company
    Digilent Inc.

  @File Name
    push_on_off.h

  @Development Environment
    MPLAB X IDE x3.61 - http://www.microchip.com/mplab/mplab-x-ide 
	XC32 1.43 - http://www.microchip.com/mplab/compilers
	PLIB 3/7/20162 - http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library
  
  @Summary
    momentary contact push button operation as Push-on / push-off switch.

  @Description
    This project implements a non-blocking push-on / push-off push button 
    operation including switch contact bouncing elimination.

  @Remarks
    Uses XC32 peripheral library. See 
 http://ww1.microchip.com/downloads/en/DeviceDoc/32bitPeripheralLibraryGuide.pdf
 http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library

  See notes in Section 12.1.4 of the PIC32MX370 users manual
    http://ww1.microchip.com/downloads/en/DeviceDoc/60001185D.pdf
 
************************************************************************** */

#ifndef _PUSH_ON_OFF_H_    /* Guard against multiple inclusion */
#define _PUSH_ON_OFF_H_


/* ************************************************************************** */
/* ************************************************************************** */
/* Section: Included Files                                                    */
/* ************************************************************************** */
/* ************************************************************************** */

/* This section lists the other files that are included in this file.
 */

/* TODO:  Include other files here if needed. */


    /* ************************************************************************** */
    /* ************************************************************************** */
    /* Section: Constants                                                         */
    /* ************************************************************************** */
    /* ************************************************************************** */

    /* ************************************************************************** */
    /** Descriptive Constant Name

      @Summary
        Brief one-line summary of the constant.
    
      @Description
        Full description, explaining the purpose and usage of the constant.
        <p>
        Additional description in consecutive paragraphs separated by HTML 
        paragraph breaks, as necessary.
        <p>
        Type "JavaDoc" in the "How Do I?" IDE toolbar for more information on tags.
    
      @Remarks
        Any additional remarks
     */
    #define BTN_DLY     30  // Debounce delay time - ms
    #define NUM_BTN     3   // Number of push buttons
    #define PB0         1   // BTNR
    #define PB1         2   // BTNC
    #define PB2         4   // BTND
    #define CN_OFF      0   // Change notification disabled
    #define CN_ON       1   // Change notification enabled

/* Macros to configure PIC pins as inputs for push button sensors */
    #define BTNL_bit    BIT_0   // RB0
    #define BTNR_bit    BIT_8   // RB8
    #define BTNU_bit    BIT_1   // RB1
    #define BTND_bit    BIT_15  // RA15
    #define BTNC_bit    BIT_0   // RF0

    // *****************************************************************************
#endif /* _EXAMPLE_FILE_NAME_H */

    // *****************************************************************************
    // *****************************************************************************
    // Section: Interface Functions
    // *****************************************************************************
    // *****************************************************************************

    /*  A brief description of a section can be given directly below the section
        banner.
     */

    // *****************************************************************************
    /**
      @Function
        int ExampleFunctionName ( int param1, int param2 ) 

      @Summary
        Brief one-line description of the function.

      @Description
        Full description, explaining the purpose and usage of the function.
        <p>
        Additional description in consecutive paragraphs separated by HTML 
        paragraph breaks, as necessary.
        <p>
        Type "JavaDoc" in the "How Do I?" IDE toolbar for more information on tags.

      @Precondition
        List and describe any required preconditions. If there are no preconditions,
        enter "None."

      @Parameters
        @param param1 Describe the first parameter to the function.
    
        @param param2 Describe the second parameter to the function.

      @Returns
        List (if feasible) and describe the return values of the function.
        <ul>
          <li>1   Indicates an error occurred
          <li>0   Indicates an error did not occur
        </ul>

      @Remarks
        Describe any special behavior not described above.
        <p>
        Any additional remarks.

      @Example
        @code
        if(ExampleFunctionName(1, 2) == 0)
        {
            return 3;
        }
     */

void push_on_offInit( void );
void push_on_off( void );


/* *****************************************************************************
 End of File
 */
