/* ************************************************************************** */
/** Descriptive File Name: audio.h - Single frequency tone generator header file
  @ Author  
    Richard Wall
  
  @ Date: 
    Created:    May 2, 2016, 9:45 AM
    Revised:    November 25, 2016
    Verified:	May 19, 2017
	 
  @Company
    Digilent Inc

  @File Name
    audio.c

  @Development Environment
    MPLAB X IDE x3.61 - http://www.microchip.com/mplab/mplab-x-ide 
	XC32 1.43 - http://www.microchip.com/mplab/compilers
	PLIB 3/7/20162 - http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library

  @Summary
    Generates one of eight single frequency tones.

  @Description

  @ Remarks:

**************************************************************************** */

#ifndef AUDIO_H
    #define AUDIO_H

    #define A_OUTbit        (1 << 14)                   //BIT_14
    #define PWM_CYCLE_RATE  160000                      // PWM frequency 
    #define PWM_ZERO_OFFSET ((int) (PWM_CYCLE_RATE >> 1)) // 50/50 PWM output
    #define PWM_MAX         ((int) ( GetPeripheralClock() / PWM_CYCLE_RATE ))
    #define Q14             (1 << 14)                   // Filter scale factor
    #define PIx2            ((float) (3.14159265359 *2))

//                                      Measured
    #define FR1             500
    #define FR2             1500
    #define FR3             2500
    #define FR4             3500

    #define FR5             4500
    #define FR6             5500
    #define FR7             6500
    #define FR8             7500

    struct coefficients
    {
        int a0;
        int a1;
        int a2;
    } ;

    typedef struct coefficients filter;

#endif	/* AUDIO_H */

/* ************************************************************************** */
/* ************************************************************************** */
/* Section: Local Variables                                                  */
/* ************************************************************************** */
/* ************************************************************************** */
/* audio_init Function Description *******************************************
 * SYNTAX:          void audio_init(void);
 * KEYWORDS:        PWM, Audio, analog output
 * DESCRIPTION:     Initializes PWM for audio output
 * PARAMETERs:      None
 *
 * RETURN VALUE:    None
 *
 * NOTES:
 *
 * END DESCRIPTION **********************************************************/
void audio_init(void);

/* start_tones FUNCTION DESCRIPTION *****************************************
 * SYNTAX:          void start_tones(int tone);
 * KEYWORDS:        Oscillator, tone generator
 * DESCRIPTION:     Set Oscillator frequency by initializing the generator
 *                  filter values
 * PARAMETERS:      int - tone selector number
 * RETURN VALUE:    None
 * Notes:           None
 *                  
 * END DESCRIPTION ***********************************************************/
void start_tones(int tone);

// End of audio.h
